@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Parameter/BinaryEkParameter.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -187,13 +187,15 @@ double BinaryEkParameter::getLogLikelihoodOne() const {
 	int64_t i;
 	int64_t j;
 	double logLikelihoodOne = 0.0, value, pdf, Scatter;
-	int64_t * Center = new int64_t[_pbDimension];
-	double * tabNbSampleInMajorModality = new double[_pbDimension];
+	//int64_t * Center = new int64_t[_pbDimension];
+    std::unique_ptr<int64_t[]> Center(new int64_t[_pbDimension]);
+	//double * tabNbSampleInMajorModality = new double[_pbDimension];
+    std::unique_ptr<double[]> tabNbSampleInMajorModality(new double[_pbDimension]);
 	int64_t nbSample = _model->getNbSample();
 	BinaryData * data = _model->getBinaryData();
 
 	// Compute Center fo One cluster //
-	getTabCenterIfOneCluster(Center, tabNbSampleInMajorModality);
+	getTabCenterIfOneCluster(Center.get(), tabNbSampleInMajorModality.get());
 
 	// Compute Scatter for One cluster //
 	value = 0.0;
@@ -207,12 +209,12 @@ double BinaryEkParameter::getLogLikelihoodOne() const {
 	// Compute the log-likelihood for one cluster (k=1) //
 	//--------------------------------------------------//
 	for (i = 0; i < nbSample; i++) {
-		pdf = computePdfOneCluster(data->_matrix[i], Center, Scatter, _tabNbModality);
+      pdf = computePdfOneCluster(data->_matrix[i], Center.get(), Scatter, _tabNbModality);
 		logLikelihoodOne += log(pdf) * data->_weight[i];
 	}
 
-	delete[] Center;
-	delete[] tabNbSampleInMajorModality;
+	//delete[] Center;
+	//delete[] tabNbSampleInMajorModality;
 
 	return logLikelihoodOne;
 }
@@ -326,21 +328,19 @@ void BinaryEkParameter::editScatter(std::ofstream & oFile, int64_t k, bool text)
 			oFile << "\t\t\t\t\t";
 			;
 		}
-		for (h = 1; h <= _tabNbModality[j]; h++) {
-			if (h == _tabCenter[k][j]) {
-				oFile << _scatter[k] << "  ";
-			}
-			else {
-				oFile << _scatter[k] / (_tabNbModality[j] - 1) << "  ";
-			}
-		}
-		oFile << endl;
-	}
+    for (h = 1; h <= _tabNbModality[j]; h++) {
+      if (h == _tabCenter[k][j])
+				putDoubleInStream(oFile, _scatter[k], "  ");
+      else
+				putDoubleInStream(oFile, _scatter[k] / (_tabNbModality[j] - 1), "  ");
+    }
+    oFile << endl;
+  }
 }
 
 // Read Scatter in input file
 //---------------------------
-void BinaryEkParameter::inputScatter(std::ifstream & fi) {
+void BinaryEkParameter::inputScatter(std::ifstream & fi, int64_t k) {
 	THROW(OtherException, internalMixmodError);
 }
 
