@@ -1,12 +1,12 @@
 /***************************************************************************
                              SRC/mixmod/Utilities/exceptions/ErrorEnumerations.h  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
 /***************************************************************************
     This file is part of MIXMOD
-
+    
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org
+    All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
 /** @file ErrorEnumerations.h
  *  @brief Enumerations for various types of errors.
@@ -228,6 +228,9 @@ enum OtherError {
 	badBinaryParameterClass,
 	internalMixmodError,
 	FunctionNotYetImplemented,
+	AllTriesGotErros,
+	AllModelsGotErros,
+    xmlFeaturesNotAvailable,
 	UnknownReason
 };
 
